import * as React from 'react';
import { getIntrinsicElementProps, ProgressBar, slot, useMergedRefs } from '@fluentui/react-components';
import { useCopilotMode, useDesignVersion } from '@fluentui-copilot/react-provider';
import { useFlair } from '@fluentui-copilot/react-flair';
import { usePrevious } from '@fluentui/react-utilities';
/**
 * Create the state required to render OutputCard.
 *
 * The returned state can be modified with hooks such as useOutputCardStyles_unstable,
 * before being passed to renderOutputCard_unstable.
 *
 * @param props - props from this instance of OutputCard
 * @param ref - reference to root HTMLElement of OutputCard
 */ export const useOutputCard_unstable = (props, ref)=>{
    const { play, targetRef, ...flairProps } = useFlair();
    const designVersion = useDesignVersion(props.designVersion);
    var _props_isLoading;
    const state = {
        flairClassName: flairProps.className,
        designVersion,
        isLoading: (_props_isLoading = props.isLoading) !== null && _props_isLoading !== void 0 ? _props_isLoading : false,
        mode: useCopilotMode(props.mode),
        components: {
            root: 'div',
            progress: ProgressBar
        },
        root: slot.always({
            ...getIntrinsicElementProps('div', {
                ref: useMergedRefs(targetRef, ref),
                ...props
            }),
            style: {
                ...flairProps.style,
                ...props.style
            }
        }, {
            elementType: 'div'
        }),
        progress: slot.optional(props.progress, {
            defaultProps: {
                shape: 'square',
                thickness: 'large',
                'aria-label': 'Loading'
            },
            elementType: ProgressBar,
            renderByDefault: false
        })
    };
    const previousIsLoading = usePrevious(state.isLoading);
    React.useEffect(()=>{
        if (!state.isLoading && previousIsLoading) {
            play();
        }
    }, [
        state.isLoading,
        previousIsLoading,
        play
    ]);
    return state;
};
