// eslint-disable
import { makeStyles, mergeClasses, slot } from '@fluentui/react-components';
import { tokens } from '@fluentui-copilot/tokens';
export const outputCardClassNames = {
    root: 'fai-OutputCard',
    progress: 'fai-OutputCard__progress'
};
const indeterminateProgressBarReducedMotion = {
    '0%': {
        opacity: '.2'
    },
    '50%': {
        opacity: '1'
    },
    '100%': {
        opacity: '.2'
    }
};
/**
 * Styles for the root slot
 */ const useStyles = makeStyles({
    root: {
        borderRadius: tokens.borderRadiusXLarge,
        display: 'flex',
        flexDirection: 'column',
        position: 'relative',
        zIndex: 0,
        backgroundColor: tokens.colorNeutralBackground1,
        boxSizing: 'border-box',
        boxShadow: tokens.shadow4,
        // to ensure a visible border in high contrast mode
        outline: `1px solid ${tokens.colorTransparentStroke}`
    },
    sidecar: {
        padding: `${tokens.spacingVerticalM} ${tokens.spacingHorizontalL}`
    },
    canvas: {
        padding: `${tokens.spacingVerticalL} ${tokens.spacingVerticalXL}`
    },
    progressRoot: {
        overflow: 'hidden',
        width: 'auto',
        overflowX: 'hidden',
        overflowY: 'hidden',
        position: 'absolute',
        bottom: 0,
        left: 0,
        right: 0,
        height: 0,
        borderBottomLeftRadius: tokens.borderRadiusLarge,
        borderBottomRightRadius: tokens.borderRadiusLarge,
        clipPath: 'polygon(0px 4px, 100% 4px, 100% 8px, 0px 8px)',
        transition: `height ${tokens.durationSlow} ${tokens.curveDecelerateMin}`
    },
    progressIsLoading: {
        height: '8px'
    },
    bar: {
        borderRadius: 0
    },
    regularProgressBarStyles: {
        height: '100%',
        backgroundImage: `linear-gradient(90deg, ${tokens.colorBrandFlair1} 35%, ${tokens.colorBrandFlair2} 70%, ${tokens.colorBrandFlair3} 92%)`
    },
    indeterminateProgressBarStyles: {
        animationDuration: '3s',
        height: '100%',
        backgroundColor: tokens.colorTransparentBackground,
        backgroundImage: `linear-gradient(90deg, rgba(0,0,0,0) 0%, ${tokens.colorBrandFlair1} 35%, ${tokens.colorBrandFlair2} 70%, ${tokens.colorBrandFlair3} 92%,  rgba(0,0,0,0))`,
        '@media screen and (prefers-reduced-motion: reduce)': {
            maxWidth: '100%',
            animationIterationCount: 'infinite',
            animationName: indeterminateProgressBarReducedMotion,
            animationDuration: '3s'
        }
    },
    indeterminateBarNotIsLoading: {
        animationPlayState: 'paused'
    }
});
const useNextStyles = makeStyles({
    root: {
        padding: `${tokens.spacingVerticalXXL} ${tokens.spacingHorizontalXXL}`,
        borderRadius: tokens.borderRadius4XL
    },
    progressRoot: {
        borderBottomLeftRadius: tokens.borderRadius4XL,
        borderBottomRightRadius: tokens.borderRadius4XL,
        // Given that the border radius is 24px and the height of the progress bar is 4px,
        // if you find the intersection between a circle centered at x=0, y=24 with radius
        // 24px and the line y=4, you find that the intersection occurs at x=13.266 which
        // makes the offset approximately 10px.
        right: '10px',
        left: '10px'
    }
});
export const useOutputCardStyles_unstable = (state)=>{
    'use no memo';
    const { flairClassName, designVersion } = state;
    const styles = useStyles();
    const nextStyles = useNextStyles();
    state.root.className = mergeClasses(outputCardClassNames.root, styles.root, styles[state.mode], flairClassName, designVersion === 'next' && nextStyles.root, state.root.className);
    if (state.progress) {
        state.progress.className = mergeClasses(outputCardClassNames.progress, styles.progressRoot, state.isLoading && styles.progressIsLoading, designVersion === 'next' && nextStyles.progressRoot, state.progress.className);
        const bar = slot.optional(state.progress.bar, {
            elementType: 'div',
            renderByDefault: true
        });
        if (bar) {
            if (state.progress.value === undefined) {
                bar.className = mergeClasses(styles.bar, styles.indeterminateProgressBarStyles, !state.isLoading && styles.indeterminateBarNotIsLoading, bar.className);
            } else {
                bar.className = mergeClasses(styles.regularProgressBarStyles, styles.bar, bar.className);
            }
            state.progress.bar = bar;
        }
    }
    return state;
};
